import requests

from django.conf import settings
from django.db import models
from django import template
from django.utils.translation import ugettext_lazy as _

from combo.data.models import CellBase
from combo.data.library import register_cell_class
from combo.utils import NothingInCacheException, sign_url


@register_cell_class
class FamilyInfosCell(CellBase):
    template_name = 'family/infos.html'
    user_dependant = True

    class Meta:
        verbose_name = _('Family Information Cell')

    @classmethod
    def is_enabled(cls):
        return hasattr(settings, 'FAMILY_SERVICE')

    def get_cell_extra_context(self):
        data = {}
        context = self.context
        if context.get('user'):
            if context.get('request') and hasattr(context['request'], 'session') and \
               context['request'].session.get('mellon_session'):
                mellon = context.get('request').session['mellon_session']
                query = '?NameID=' + mellon['name_id_content']
                query += '&orig=' + context['request'].get_host()
                url = sign_url(settings.FAMILY_SERVICE.get('url') + '/family/' + query,
                               settings.FAMILY_SERVICE.get('signature_key'))
                r = requests.get(url)
                data.update({'family': r.json()})
        return data

    def render(self, context):
        self.context = context
        if not context.get('synchronous'):
            raise NothingInCacheException()
        return super(FamilyInfosCell, self).render(context)
